==> 0.0.2.tar.gz: lib/examples/listview_demo.dart <==
import 'package:yflutter_widgets/widgets/listview/ylistview.dart';
import 'package:flutter/material.dart';

class ListViewDemo extends StatelessWidget {
  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        title: Text("ListView Demo"),
      ),
      body: YListView(
        type: HeaderType.Normal,
        borderType: BoarderType.ListWhole,
        headerHeight: 150,
        numOfSection: _sectionCount,
        numberOfRowsInSection: _numberOfRowsInSection,
        sectionHeight: _sectionHeight,
        cellHeight: _cellHeight,
        sectionHeader: _headerOfSectionAtIndex,
        cell: _cellOfRowAtIndex,
      ),
    );
  }

  int _sectionCount = 3;

  // Get row count.
  int _numberOfRowsInSection(int sectionIndex) {
    if (sectionIndex == 0) {
      return 5;
    } else if (sectionIndex == 1) {
      return 10;
    } else {
      return 20;
    }
  }

  // Section header widget builder.
  Widget _headerOfSectionAtIndex(BuildContext context, int sectionIndex) {
    return InkWell(
      onTap: () {
        print('click section header. -> section:$sectionIndex');
      },
      child: Container(
        alignment: Alignment.centerLeft,
        padding: EdgeInsets.only(left: 16.0),
        height: 100,
        child: Text('I am section header -> section:$sectionIndex'),
      ),
    );
  }

  // cell item widget builder.
  Widget _cellOfRowAtIndex(BuildContext context, int sectionIndex, int rowIndex) {
    return InkWell(
      onTap: () {
        print('click cell item. -> section:$sectionIndex row:$rowIndex');
      },
      child: Container(
        padding: EdgeInsets.only(left: 16.0),
        alignment: Alignment.centerLeft,
        decoration: BoxDecoration(
            border: Border(
                bottom: BorderSide(
                  color: Color.fromRGBO(240, 240, 240, 1),
                ))),
        height: 50.0,
        child: Text('I am cell -> section:$sectionIndex  row$rowIndex'),
      ),
    );
  }

  // Each section header height;
  double _sectionHeight(BuildContext context, int sectionIndex) {
    return 50.0;
  }

  // Each cell item widget height.
  double _cellHeight(BuildContext context, int section, int rowIndex) {
    return 50.0;
  }
}

==> 0.0.5.tar.gz: lib/examples/listview_demo.dart <==
import 'package:yflutter_widgets/widgets/listview/ylistview.dart';
import 'package:flutter/material.dart';

class ListViewDemo extends StatelessWidget {
  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        title: Text("ListView Demo"),
      ),
      body: YListView(
        type: HeaderType.Zoom,
        borderType: BorderType.None,
        listHeader: Container(color: Colors.blue,),
        headerHeight: 120,
        numOfSection: _sectionCount,
        numberOfRowsInSection: _numberOfRowsInSection,
        sectionHeight: _sectionHeight,
        cellHeight: _cellHeight,
        sectionHeader: _headerOfSectionAtIndex,
        cell: _cellOfRowAtIndex,
      ),
    );
  }

  int _sectionCount = 3;

  // Get row count.
  int _numberOfRowsInSection(int sectionIndex) {
    if (sectionIndex == 0) {
      return 5;
    } else if (sectionIndex == 1) {
      return 10;
    } else {
      return 20;
    }
  }

  // Section header widget builder.
  Widget _headerOfSectionAtIndex(BuildContext context, int sectionIndex) {
    return InkWell(
      onTap: () {
        print('click section header. -> section:$sectionIndex');
      },
      child: Container(
        alignment: Alignment.centerLeft,
        padding: EdgeInsets.only(left: 16.0),
        height: 100,
        child: Text('I am section header -> section:$sectionIndex'),
      ),
    );
  }

  // cell item widget builder.
  Widget _cellOfRowAtIndex(BuildContext context, int sectionIndex, int rowIndex) {
    return InkWell(
      onTap: () {
        print('click cell item. -> section:$sectionIndex row:$rowIndex');
      },
      child: Container(
        padding: EdgeInsets.only(left: 16.0),
        alignment: Alignment.centerLeft,
        decoration: BoxDecoration(
            border: Border(
                bottom: BorderSide(
                  color: Color.fromRGBO(240, 240, 240, 1),
                ))),
        height: 50.0,
        child: Text('I am cell -> section:$sectionIndex  row$rowIndex'),
      ),
    );
  }

  // Each section header height;
  double _sectionHeight(BuildContext context, int sectionIndex) {
    return 50.0;
  }

  // Each cell item widget height.
  double _cellHeight(BuildContext context, int section, int rowIndex) {
    return 50.0;
  }
}
